@@ -31,7 +31,7 @@
 #include <e-gw-connection.h>
 #include <libedataserverui/e-passwords.h>
 #include "e-util/e-alert-dialog.h"
-#include <libecal/e-cal.h>
+#include <libecal/e-cal-client.h>
 #include <shell/e-shell.h>
 #include <e-util/e-account-utils.h>
 
@@ -503,18 +503,18 @@ get_addressbook_names_from_server (gchar *source_url)
 		count++;
 		/*we have to uncache the password before prompting again*/
 		if (failed_auth) {
-			e_passwords_forget_password ("Groupwise", key);
+			e_passwords_forget_password (NULL, key);
 			password = NULL;
 		}
 
-		password = e_passwords_get_password ("Groupwise", key);
+		password = e_passwords_get_password (NULL, key);
 		if (!password) {
 			/* Translators: First %s is the server name, second %s is user name */
 			password_prompt = g_strdup_printf (_("Enter password for %s (user %s)"),
 					poa_address, url->user);
 			prompt = g_strconcat (failed_auth ? failed_auth : "", password_prompt, NULL);
 			g_free (password_prompt);
-			password = e_passwords_ask_password (prompt, "Groupwise", key, prompt,
+			password = e_passwords_ask_password (prompt, NULL, key, prompt,
 					flags, &remember,
 					NULL);
 			g_free (prompt);
@@ -942,16 +942,16 @@ prune_proxies (void) {
 	GError *err = NULL;
 	const gchar *parent_id_name = NULL;
 	gint i;
-	ECalSourceType types[] = { E_CAL_SOURCE_TYPE_EVENT,
-				    E_CAL_SOURCE_TYPE_TODO,
-				    E_CAL_SOURCE_TYPE_JOURNAL
-				  };
+	ECalClientSourceType types[] = { E_CAL_CLIENT_SOURCE_TYPE_EVENTS,
+					 E_CAL_CLIENT_SOURCE_TYPE_TASKS,
+					 E_CAL_CLIENT_SOURCE_TYPE_MEMOS
+					};
 
 	account_list = e_get_account_list ();
 	e_account_list_prune_proxies (account_list);
 
 	for (i=0; i<3; i++) {
-	if (e_cal_get_sources (&sources, types[i], &err)) {
+	if (e_cal_client_get_sources (&sources, types[i], &err)) {
 		/* peek groupwise id and prune for proxies. */
 		groups = e_source_list_peek_groups (sources);
 		for (l = groups; l != NULL;) {
